Migration

Struct Migration 

pub struct Migration {
    pub P: RistrettoPoint,
    pub Q: RistrettoPoint,
    pub lox_id: Scalar,
    pub from_bucket: Scalar,
    pub to_bucket: Scalar,
    pub migration_type: Scalar,
}
A migration credential.

This credential authorizes the holder of the Lox credential with the given id to switch from bucket from_bucket to bucket to_bucket. The migration_type attribute is 0 for trust upgrade migrations (moving from a 1-bridge untrusted bucket to a 3-bridge trusted bucket) and 1 for blockage migrations (moving buckets because the from_bucket has been blocked).

Fields

P: RistrettoPointQ: RistrettoPointlox_id: Scalarfrom_bucket: Scalarto_bucket: Scalarmigration_type: Scalar