pub struct MigrationKey {
pub P: RistrettoPoint,
pub Q: RistrettoPoint,
pub lox_id: Scalar,
pub from_bucket: Scalar,
}Expand description
The migration key credential.
This credential is never actually instantiated. It is an implicit credential on attributes lox_id and from_bucket. This credential type does have an associated private and public key, however. The idea is that if a user proves (in zero knowledge) that their Lox credential entitles them to migrate from one bucket to another, the BA will issue a (blinded, so the BA will not know the values of the attributes or of Q) MAC on this implicit credential. The Q value will then be used (actually, a hash of lox_id, from_bucket, and Q) to encrypt the to_bucket, P, and Q fields of a Migration credential. That way, people entitled to migrate buckets can receive a Migration credential with their new bucket, without the BA learning either their old or new buckets.
Fields
P: RistrettoPointQ: RistrettoPointlox_id: Scalarfrom_bucket: Scalar