pub enum MigrationType {
TrustUpgrade,
Blockage,
}Expand description
The type of migration table: TrustUpgrade is for migrations from untrusted (level 0) 1-bridge buckets to trusted (level 1) 3-bridge buckets. Blockage is for migrations that drop you down two levels (level 3 to 1, level 4 to 2) because the bridges in your current bucket were blocked.
Variants