pub enum ProofError {
VerificationFailure,
BatchSizeMismatch,
}Expand description
An error during proving or verification, such as a verification failure.
Variants
VerificationFailure
Something is wrong with the proof, causing a verification failure.
BatchSizeMismatch
Occurs during batch verification if the batch parameters are mis-sized.