pub struct BucketReachability {
pub P: RistrettoPoint,
pub Q: RistrettoPoint,
pub date: Scalar,
pub bucket: Scalar,
}Expand description
The Bucket Reachability credential.
Each day, a credential of this type is put in each bucket that has at least a (configurable) threshold number of bridges that have not been blocked as of the given date. Users can present this credential (in zero knowledge) with today’s date to prove that the bridges in their bucket have not been blocked, in order to gain a trust level.
Fields
P: RistrettoPointQ: RistrettoPointdate: Scalarbucket: ScalarTrait Implementations
Sourceimpl Debug for BucketReachability
impl Debug for BucketReachability
Sourceimpl<'de> Deserialize<'de> for BucketReachability
impl<'de> Deserialize<'de> for BucketReachability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more