pub struct Invitation {
pub P: RistrettoPoint,
pub Q: RistrettoPoint,
pub inv_id: Scalar,
pub date: Scalar,
pub bucket: Scalar,
pub blockages: Scalar,
}Expand description
The Invitation credential.
These credentials allow a Lox user (the inviter) of sufficient trust (level 2 or higher) to invite someone else (the invitee) to join the system. The invitee ends up at trust level 1, in the same bucket as the inviter, and inherits the inviter’s blockages count (so that you can’t clear your blockages count simply by inviting yourself). Invitations expire after some amount of time.
Fields
P: RistrettoPointQ: RistrettoPointinv_id: Scalardate: Scalarbucket: Scalarblockages: ScalarTrait Implementations
Sourceimpl Debug for Invitation
impl Debug for Invitation
Sourceimpl<'de> Deserialize<'de> for Invitation
impl<'de> Deserialize<'de> for Invitation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more