CompactProof

Struct CompactProof 

pub struct CompactProof {
    pub challenge: Scalar,
    pub responses: Vec<Scalar>,
}
A Schnorr proof in compact format.

This performs the standard folklore optimization of sending the challenge in place of the commitments to the prover’s randomness. However, this optimization prevents batch verification.

This proof has m+1 32-byte elements, where m is the number of secret variables. This means there is no space savings for a CompactProof over a BatchableProof when there is only one statement.

Fields

challenge: Scalar

The Fiat-Shamir challenge.

responses: Vec<Scalar>

The prover’s responses, one per secret variable.